@@ -18,6 +18,19 @@ class ReqIFDataTypeDefinitionString:
         self.long_name: Optional[str] = long_name
         self.max_length: Optional[str] = max_length
 
+    @staticmethod
+    def create(
+        identifier: str,
+    ) -> "ReqIFDataTypeDefinitionString":
+        return ReqIFDataTypeDefinitionString(
+            is_self_closed=True,
+            description=None,
+            identifier=identifier,
+            last_change=None,
+            long_name=None,
+            max_length=None,
+        )
+
 
 class ReqIFDataTypeDefinitionInteger:
     def __init__(
@@ -50,6 +63,17 @@ class ReqIFEnumValue:
         self.other_content: Optional[str] = other_content
         self.long_name: Optional[str] = long_name
 
+    @staticmethod
+    def create(identifier: str, key: str):
+        return ReqIFEnumValue(
+            description=None,
+            identifier=identifier,
+            last_change=None,
+            key=key,
+            other_content=None,
+            long_name=None,
+        )
+
 
 class ReqIFDataTypeDefinitionEnumeration:  # pylint: disable=too-many-instance-attributes # noqa:E501
     def __init__(  # pylint: disable=too-many-arguments
@@ -72,6 +96,19 @@ class ReqIFDataTypeDefinitionEnumeration:  # pylint: disable=too-many-instance-a
         self.values: Optional[List[ReqIFEnumValue]] = values
         self.values_map = values_map
 
+    @staticmethod
+    def create(identifier: str, values: Optional[List[ReqIFEnumValue]]):
+        return ReqIFDataTypeDefinitionEnumeration(
+            is_self_closed=False,
+            description=None,
+            identifier=identifier,
+            last_change=None,
+            long_name=None,
+            multi_valued=False,
+            values=values,
+            values_map={},
+        )
+
 
 class ReqIFDataTypeDefinitionXHTML:
     def __init__(  # pylint: disable=too-many-arguments
